@@ -694,6 +694,8 @@ char *yon_char_unite(const char *source, ...);
 
 char *yon_cut(char *source, int size, int startpos);
 
+int yon_char_check_element(char *target, char *element, char *divider);
+
 /**
  * @brief Check if string begins with substring.
  * 
@@ -1205,6 +1207,8 @@ config_str yon_config_get_save_parameters_by_key(int *size, ...);
 
 config_str yon_config_get_save_parameters(int *size);
 
+char *yon_config_parameter_wrap(char *parameter_key);
+
 /**yon_config_parameter_prepare_command(char *command, char *path, char *section, char *parameter)
  * 
 */
